import os
import pkgutil
import subprocess
import tempfile
import sys

class import_(object):
    def __init__(self, path):
        self.path = path
        self.proc = None

    def __enter__(self):
        env = {'GIT_DIR': os.path.join(self.path, '.git')}

        revs = subprocess.Popen([
            'git', 'rev-list', '--all'
        ], stdout=subprocess.PIPE, env=env).stdout
        valid = set(rev.strip() for rev in revs)

        with tempfile.NamedTemporaryFile(delete=False) as f:
            self.marks_path = f.name
            f.writelines(
                '%s\n' % line
                for line in pkgutil.get_data('data', 'marks.git').split('\n')
                if line and line.split()[1] in valid
            )

        self.proc = subprocess.Popen([
            'git', 'fast-import', '--stats',
                '--import-marks={}'.format(self.marks_path),
        ], stdin=subprocess.PIPE, env=env)
        return self

    def __exit__(self, *args):
        self.proc.stdin.close()
        self.proc.wait()
        os.remove(self.marks_path)

    def write(self, line):
        self.proc.stdin.write(line)

    def writelines(self, lines):
        for line in lines:
            self.write(line)
